@@ -471,6 +471,39 @@ enum Command {
         context: Option<String>,
     },
 
+    #[structopt(
+        about = "Just register named cluster via API (no interaction with K8s cluster",
+        visible_alias = "jrc",
+        display_order(1000),
+        setting(clap::AppSettings::Hidden)
+    )]
+    JustRegisterCluster {
+        #[structopt(help = "Cluster name")]
+        name: v0::ClusterName,
+        #[structopt(
+            help = "Namespace to install statehub components",
+            long,
+            default_value = "statehub-system",
+            visible_alias = "ns"
+        )]
+        namespace: String,
+        #[structopt(help = "K8s cluster provider", long, default_value = "generic")]
+        provider: v0::Provider,
+        #[structopt(long, short, help = "Location definition", alias = "location")]
+        locations: Vec<Location>,
+    },
+
+    #[structopt(
+        about = "Just unregister named cluster via API (no interaction with K8s cluster)",
+        visible_aliases = &["jurc", "juc"],
+        display_order(1000),
+        setting(clap::AppSettings::Hidden)
+    )]
+    JustUnregisterCluster {
+        #[structopt(help = "Cluster name")]
+        name: v0::ClusterName,
+    },
+
     #[structopt(
         about = "Save cluster token",
         visible_alias = "sct",
@@ -642,6 +675,8 @@ impl Command {
             Command::ListVolumes { .. } => true,
             Command::ShowVolumes { .. } => true,
             Command::UninstallStatehub { .. } => false,
+            Command::JustRegisterCluster { .. } => true,
+            Command::JustUnregisterCluster { .. } => true,
             Command::SaveClusterToken { .. } => false,
             Command::SetupConfigmap { .. } => false,
             Command::InstallClusterCrd { .. } => false,
@@ -864,6 +899,17 @@ impl Cli {
 
                 statehub.uninstall_statehub(kubectls, force).await
             }
+            Command::JustRegisterCluster {
+                name,
+                namespace,
+                provider,
+                locations,
+            } => {
+                statehub
+                    .just_register_cluster(name, namespace, provider, locations)
+                    .await
+            }
+            Command::JustUnregisterCluster { name } => statehub.just_unregister_cluster(name).await,
             Command::SaveClusterToken {
                 namespace,
                 cluster_token,
@@ -1142,6 +1188,26 @@ impl StateHub {
         Ok(())
     }
 
+    async fn just_register_cluster(
+        &self,
+        name: v0::ClusterName,
+        namespace: String,
+        provider: v0::Provider,
+        locations: Vec<Location>,
+    ) -> anyhow::Result<()> {
+        self.api
+            .register_cluster(&name, &namespace, provider, &locations)
+            .await
+            .print(&self.stdout, &self.style, self.json)
+    }
+
+    async fn just_unregister_cluster(&self, name: v0::ClusterName) -> anyhow::Result<()> {
+        self.api
+            .unregister_cluster(&name)
+            .await
+            .print(&self.stdout, &self.style, self.json)
+    }
+
     async fn add_location(
         &self,
         state: v0::StateName,
